@@ -143,7 +143,7 @@ export const yamlResolverSchema: JSONSchema7 = {
   properties: {
     url: {
       type: 'string',
-      pattern: '^http.*.yaml$',
+      pattern: '^http.*',
     },
   },
   required: ['url'],
@@ -237,3 +237,41 @@ export const templateStartedSchema: JSONSchema7 = {
     },
   },
 };
+
+export const personalAccessTokenBodySchema: JSONSchema7 = {
+  type: 'object',
+  properties: {
+    cheUserId: {
+      type: 'string',
+    },
+    tokenName: {
+      type: 'string',
+    },
+    tokenData: {
+      type: 'string',
+    },
+    gitProviderEndpoint: {
+      type: 'string',
+    },
+    gitProvider: {
+      type: 'string',
+    },
+    gitProviderOrganization: {
+      type: 'string',
+    },
+  },
+  required: ['cheUserId', 'tokenName', 'tokenData', 'gitProviderEndpoint', 'gitProvider'],
+};
+
+export const personalAccessTokenParamsSchema: JSONSchema7 = {
+  type: 'object',
+  properties: {
+    namespace: {
+      type: 'string',
+    },
+    tokenName: {
+      type: 'string',
+    },
+  },
+  required: ['namespace', 'tokenName'],
+};
