@@ -22,6 +22,7 @@ import { LogsApiService } from '../services/logsApi';
 import { PodApiService } from '../services/podApi';
 import { ServerConfigApiService } from '../services/serverConfigApi';
 import { UserProfileApiService } from '../services/userProfileApi';
+import { GettingStartedSamplesApiService } from '../services/gettingStartedSamplesApi';
 
 jest.mock('../services/devWorkspaceApi.ts');
 
@@ -49,5 +50,6 @@ describe('DevWorkspace client', () => {
     expect(client.podApi).toBeInstanceOf(PodApiService);
     expect(client.serverConfigApi).toBeInstanceOf(ServerConfigApiService);
     expect(client.userProfileApi).toBeInstanceOf(UserProfileApiService);
+    expect(client.gettingStartedSampleApi).toBeInstanceOf(GettingStartedSamplesApiService);
   });
 });
