@@ -107,7 +107,12 @@ export class ServerConfigApiService implements IServerConfigApi {
   }
 
   getDefaultDevfileRegistryUrl(cheCustomResource: CustomResourceDefinition): string {
-    return cheCustomResource.status?.devfileRegistryURL || '';
+    let devfileRegistryURL = cheCustomResource.status?.devfileRegistryURL || '';
+    if (devfileRegistryURL && !devfileRegistryURL.endsWith('/')) {
+      devfileRegistryURL += '/';
+    }
+
+    return devfileRegistryURL;
   }
 
   getDefaultPluginRegistryUrl(cheCustomResource: CustomResourceDefinition): string {
@@ -201,4 +206,10 @@ export class ServerConfigApiService implements IServerConfigApi {
   getWorkspaceStartTimeout(cheCustomResource: CustomResourceDefinition): number {
     return cheCustomResource.spec.devEnvironments?.startTimeoutSeconds || startTimeoutSeconds;
   }
+
+  getDashboardLogo(
+    cheCustomResource: CustomResourceDefinition,
+  ): { base64data: string; mediatype: string } | undefined {
+    return cheCustomResource.spec.components?.dashboard?.branding?.logo;
+  }
 }
