@@ -14,7 +14,6 @@ const base = require('../../jest.config.base');
 
 module.exports = {
   ...base,
-  name: 'dashboard-frontend',
   displayName: 'Dashboard Frontend',
   moduleDirectories: ['node_modules', '../../node_modules', 'src'],
   moduleNameMapper: {
@@ -25,11 +24,17 @@ module.exports = {
       'vscode-languageserver-protocol/lib/common/utils/is',
     'vscode-languageserver-protocol/lib/main': 'vscode-languageserver-protocol/lib/node/main',
   },
-  globals: {
-    'ts-jest': {
-      tsconfig: 'tsconfig.test.json',
-      diagnostics: true,
-    },
+  modulePathIgnorePatterns: [
+    '__mocks__/index.tsx',
+  ],
+  testEnvironment: 'jsdom',
+  transform: {
+    '^.*\\.tsx?$': [
+      'ts-jest',
+      {
+        diagnostics: true,
+      },
+    ],
   },
   setupFilesAfterEnv: ['./jest.setup.ts'],
   setupFiles: ['./src/inversify.config.ts'],
@@ -46,10 +51,10 @@ module.exports = {
   ],
   coverageThreshold: {
     global: {
-      statements: 80,
+      statements: 81,
       branches: 85,
       functions: 77,
-      lines: 80,
+      lines: 81,
     },
   },
 };
