@@ -12,13 +12,12 @@
 
 import React from 'react';
 import { connect, ConnectedProps } from 'react-redux';
-import { Page } from '@patternfly/react-core';
+import { Brand, Page } from '@patternfly/react-core';
 import { History } from 'history';
 import { matchPath } from 'react-router';
 import Header from './Header';
 import Sidebar from './Sidebar';
 import StoreErrorsAlert from './StoreErrorsAlert';
-import { ThemeVariant } from './themeVariant';
 import { AppState } from '../store';
 import { lazyInject } from '../inversify.config';
 import { IssuesReporterService } from '../services/bootstrap/issuesReporter';
@@ -30,8 +29,8 @@ import { ROUTE } from '../Routes/routes';
 import { selectBranding } from '../store/Branding/selectors';
 import { ToggleBarsContext } from '../contexts/ToggleBars';
 import { signOut } from '../services/helpers/login';
+import { selectDashboardLogo } from '../store/ServerConfig/selectors';
 
-const THEME_KEY = 'theme';
 const IS_MANAGED_SIDEBAR = false;
 
 type Props = MappedProps & {
@@ -41,7 +40,6 @@ type Props = MappedProps & {
 type State = {
   isSidebarVisible: boolean;
   isHeaderVisible: boolean;
-  theme: ThemeVariant;
 };
 
 export class Layout extends React.PureComponent<Props, State> {
@@ -51,13 +49,9 @@ export class Layout extends React.PureComponent<Props, State> {
   constructor(props: Props) {
     super(props);
 
-    const theme: ThemeVariant =
-      (window.sessionStorage.getItem(THEME_KEY) as ThemeVariant) || ThemeVariant.DARK;
-
     this.state = {
       isHeaderVisible: true,
       isSidebarVisible: true,
-      theme,
     };
   }
 
@@ -67,11 +61,6 @@ export class Layout extends React.PureComponent<Props, State> {
     });
   }
 
-  private changeTheme(theme: ThemeVariant): void {
-    this.setState({ theme });
-    window.sessionStorage.setItem(THEME_KEY, theme);
-  }
-
   private hideAllBars(): void {
     this.setState({
       isHeaderVisible: false,
@@ -112,10 +101,13 @@ export class Layout extends React.PureComponent<Props, State> {
       }
     }
 
-    const { isHeaderVisible, isSidebarVisible, theme } = this.state;
-    const { history } = this.props;
+    const { isHeaderVisible, isSidebarVisible } = this.state;
+    const { history, branding, dashboardLogo } = this.props;
 
-    const logoUrl = this.props.branding.logoFile;
+    const logoSrc =
+      dashboardLogo !== undefined
+        ? `data:${dashboardLogo.mediatype};base64,${dashboardLogo.base64data}`
+        : branding.logoFile;
 
     return (
       <ToggleBarsContext.Provider
@@ -129,10 +121,9 @@ export class Layout extends React.PureComponent<Props, State> {
             <Header
               history={history}
               isVisible={isHeaderVisible}
-              logoUrl={logoUrl}
+              logo={<Brand src={logoSrc} alt="Logo" />}
               logout={() => signOut()}
               toggleNav={() => this.toggleNav()}
-              changeTheme={theme => this.changeTheme(theme)}
             />
           }
           sidebar={
@@ -140,7 +131,6 @@ export class Layout extends React.PureComponent<Props, State> {
               isManaged={IS_MANAGED_SIDEBAR}
               isNavOpen={isSidebarVisible}
               history={history}
-              theme={theme}
             />
           }
           isManagedSidebar={IS_MANAGED_SIDEBAR}
@@ -158,6 +148,7 @@ export class Layout extends React.PureComponent<Props, State> {
 
 const mapStateToProps = (state: AppState) => ({
   branding: selectBranding(state),
+  dashboardLogo: selectDashboardLogo(state),
 });
 
 const connector = connect(mapStateToProps);
