@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -13,7 +13,7 @@
 import React from 'react';
 import { Props, State } from '..';
 
-export default class LogsTab extends React.PureComponent<Props, State> {
+export default class WorkspaceLogs extends React.PureComponent<Props, State> {
   render(): React.ReactNode {
     return <div>Dummy Logs</div>;
   }
