@@ -17,18 +17,20 @@ import React from 'react';
 import { connect, ConnectedProps } from 'react-redux';
 import { WorkspaceParams } from '../../../../Routes/routes';
 import { isAvailableEndpoint } from '../../../../services/helpers/api-ping';
-import { delay } from '../../../../services/helpers/delay';
-import { DisposableCollection } from '../../../../services/helpers/disposable';
 import { findTargetWorkspace } from '../../../../services/helpers/factoryFlow/findTargetWorkspace';
 import { AlertItem, LoaderTab } from '../../../../services/helpers/types';
 import { Workspace } from '../../../../services/workspace-adapter';
 import { AppState } from '../../../../store';
 import * as WorkspaceStore from '../../../../store/Workspaces';
 import { selectAllWorkspaces } from '../../../../store/Workspaces/selectors';
-import { MIN_STEP_DURATION_MS, TIMEOUT_TO_GET_URL_SEC } from '../../const';
+import { TIMEOUT_TO_GET_URL_SEC } from '../../const';
 import { ProgressStep, ProgressStepProps, ProgressStepState } from '../../ProgressStep';
 import { ProgressStepTitle } from '../../StepTitle';
 import { TimeLimit } from '../../TimeLimit';
+import {
+  applyRestartDefaultLocation,
+  applyRestartInSafeModeLocation,
+} from '../StartWorkspace/prepareRestart';
 
 export type Props = MappedProps &
   ProgressStepProps & {
@@ -38,7 +40,6 @@ export type State = ProgressStepState;
 
 class StartingStepOpenWorkspace extends ProgressStep<Props, State> {
   protected readonly name = 'Open IDE';
-  protected readonly toDispose = new DisposableCollection();
 
   constructor(props: Props) {
     super(props);
@@ -65,11 +66,13 @@ class StartingStepOpenWorkspace extends ProgressStep<Props, State> {
   }
 
   public async componentDidUpdate() {
-    this.toDispose.dispose();
-
     this.init();
   }
 
+  public componentWillUnmount(): void {
+    this.toDispose.dispose();
+  }
+
   public shouldComponentUpdate(nextProps: Props, nextState: State): boolean {
     // active step changed
     if (this.props.distance !== nextProps.distance) {
@@ -94,10 +97,6 @@ class StartingStepOpenWorkspace extends ProgressStep<Props, State> {
     return false;
   }
 
-  public componentWillUnmount(): void {
-    this.toDispose.dispose();
-  }
-
   protected handleRestart(alertKey: string, tab: LoaderTab): void {
     this.props.onHideError(alertKey);
 
@@ -113,8 +112,6 @@ class StartingStepOpenWorkspace extends ProgressStep<Props, State> {
   }
 
   protected async runStep(): Promise<boolean> {
-    await delay(MIN_STEP_DURATION_MS);
-
     const { matchParams } = this.props;
     const workspace = this.findTargetWorkspace(this.props);
 
@@ -165,18 +162,24 @@ class StartingStepOpenWorkspace extends ProgressStep<Props, State> {
       actionCallbacks: [
         {
           title: 'Restart',
-          callback: () => this.handleRestart(key, LoaderTab.Progress),
+          callback: () => {
+            applyRestartDefaultLocation(this.props.history.location);
+            this.handleRestart(key, LoaderTab.Progress);
+          },
         },
         {
-          title: 'Open in Verbose mode',
-          callback: () => this.handleRestart(key, LoaderTab.Logs),
+          title: 'Restart with default devfile',
+          callback: () => {
+            applyRestartInSafeModeLocation(this.props.history.location);
+            this.handleRestart(key, LoaderTab.Progress);
+          },
         },
       ],
     };
   }
 
   render(): React.ReactNode {
-    const { distance } = this.props;
+    const { distance, hasChildren } = this.props;
     const { name, lastError } = this.state;
 
     const isActive = distance === 0;
@@ -188,7 +191,12 @@ class StartingStepOpenWorkspace extends ProgressStep<Props, State> {
         {isActive && (
           <TimeLimit timeLimitSec={TIMEOUT_TO_GET_URL_SEC} onTimeout={() => this.handleTimeout()} />
         )}
-        <ProgressStepTitle distance={distance} isError={isError} isWarning={isWarning}>
+        <ProgressStepTitle
+          distance={distance}
+          hasChildren={hasChildren}
+          isError={isError}
+          isWarning={isWarning}
+        >
           {name}
         </ProgressStepTitle>
       </React.Fragment>
