@@ -94,7 +94,7 @@ export enum WorkspaceDetailsTab {
 
 export enum WorkspaceAction {
   OPEN_IDE = 'Open',
-  START_DEBUG_AND_OPEN_LOGS = 'Open in verbose mode',
+  START_DEBUG_AND_OPEN_LOGS = 'Open in Debug mode',
   START_IN_BACKGROUND = 'Start in background',
   STOP_WORKSPACE = 'Stop Workspace',
   DELETE_WORKSPACE = 'Delete Workspace',
