@@ -18,7 +18,7 @@ import {
 } from '@devfile/api';
 import { api } from '@eclipse-che/common';
 import { WorkspacesDefaultPlugins } from 'dashboard-frontend/src/store/Plugins/devWorkspacePlugins';
-import { inject, injectable } from 'inversify';
+import { decorate, inject, injectable } from 'inversify';
 import { load } from 'js-yaml';
 import { cloneDeep, isEqual } from 'lodash';
 import * as DwApi from '../../dashboard-backend-client/devWorkspaceApi';
@@ -73,6 +73,8 @@ export interface ICheEditorYaml {
   };
 }
 
+decorate(injectable(), WorkspaceClient);
+
 /**
  * This class manages the connection between the frontend and the devworkspace typescript library
  */
@@ -235,7 +237,7 @@ export class DevWorkspaceClient extends WorkspaceClient {
    * propagate the plugin registry, plugin internal registry,
    * and dashboard URLs into the components containers
    */
-  private addEnvVarsToContainers(
+  public addEnvVarsToContainers(
     components:
       | V1alpha2DevWorkspaceSpecTemplateComponents[]
       | V1alpha2DevWorkspaceTemplateSpecComponents[]
